@@ -12,21 +12,22 @@ except ImportError:  # pragma: no cover
     from dummy_threading import RLock
 
 from . import keys
+from .fifo import FIFOCache
 from .lfu import LFUCache
 from .lru import LRUCache
+from .mru import MRUCache
 from .rr import RRCache
 from .ttl import TTLCache
 
-__all__ = ('lfu_cache', 'lru_cache', 'rr_cache', 'ttl_cache')
+__all__ = ("lfu_cache", "lru_cache", "mru_cache", "rr_cache", "ttl_cache")
 
 
-_CacheInfo = collections.namedtuple('CacheInfo', [
-    'hits', 'misses', 'maxsize', 'currsize'
-])
+_CacheInfo = collections.namedtuple(
+    "CacheInfo", ["hits", "misses", "maxsize", "currsize"]
+)
 
 
 class _UnboundCache(dict):
-
     @property
     def maxsize(self):
         return None
@@ -63,12 +64,12 @@ def _cache(cache, typed):
                 except KeyError:
                     stats[1] += 1
             v = func(*args, **kwargs)
+            # in case of a race, prefer the item already in the cache
             try:
                 with lock:
-                    cache[k] = v
+                    return cache.setdefault(k, v)
             except ValueError:
-                pass  # value too large
-            return v
+                return v  # value too large
 
         def cache_info():
             with lock:
@@ -86,12 +87,27 @@ def _cache(cache, typed):
 
         wrapper.cache_info = cache_info
         wrapper.cache_clear = cache_clear
-        wrapper.cache_parameters = lambda: {'maxsize': maxsize, 'typed': typed}
+        wrapper.cache_parameters = lambda: {"maxsize": maxsize, "typed": typed}
         functools.update_wrapper(wrapper, func)
         return wrapper
+
     return decorator
 
 
+def fifo_cache(maxsize=128, typed=False):
+    """Decorator to wrap a function with a memoizing callable that saves
+    up to `maxsize` results based on a First In First Out (FIFO)
+    algorithm.
+
+    """
+    if maxsize is None:
+        return _cache(_UnboundCache(), typed)
+    elif callable(maxsize):
+        return _cache(FIFOCache(128), typed)(maxsize)
+    else:
+        return _cache(FIFOCache(maxsize), typed)
+
+
 def lfu_cache(maxsize=128, typed=False):
     """Decorator to wrap a function with a memoizing callable that saves
     up to `maxsize` results based on a Least Frequently Used (LFU)
@@ -120,6 +136,19 @@ def lru_cache(maxsize=128, typed=False):
         return _cache(LRUCache(maxsize), typed)
 
 
+def mru_cache(maxsize=128, typed=False):
+    """Decorator to wrap a function with a memoizing callable that saves
+    up to `maxsize` results based on a Most Recently Used (MRU)
+    algorithm.
+    """
+    if maxsize is None:
+        return _cache(_UnboundCache(), typed)
+    elif callable(maxsize):
+        return _cache(MRUCache(128), typed)(maxsize)
+    else:
+        return _cache(MRUCache(maxsize), typed)
+
+
 def rr_cache(maxsize=128, choice=random.choice, typed=False):
     """Decorator to wrap a function with a memoizing callable that saves
     up to `maxsize` results based on a Random Replacement (RR)
